@@ -1,7 +1,7 @@
 
-package CLI::latextable;
+package cli::tsv::latextable ;
 
-our $VERSION = 0.11 ;
+our $VERSION = 0.111 ;
 
 =encoding utf8
 =pod
